/*****************************************************************************
 * Copyright (c) 2014-2026 OpenRCT2 developers
 *
 * For a complete list of all authors, please refer to contributors.md
 * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
 *
 * OpenRCT2 is licensed under the GNU General Public License version 3.
 *****************************************************************************/

#include "../../../SpriteIds.h"
#include "../../../drawing/Drawing.h"
#include "../../../ride/TrackPaint.h"
#include "../../tile_element/Paint.Tunnel.h"
#include "../../tile_element/Segment.h"
#include "WoodenRollerCoaster.hpp"

using namespace OpenRCT2;
using namespace OpenRCT2::WoodenRC;

// static constexpr TunnelGroup kTunnelGroup = TunnelGroup::Square;

enum
{
    SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_LEFT_BANK_0 = SPR_CSG_BEGIN + 65447,
    SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_LEFT_BANK_1 = SPR_CSG_BEGIN + 65448,
    SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_LEFT_BANK_2 = SPR_CSG_BEGIN + 65449,
    SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_LEFT_BANK_3 = SPR_CSG_BEGIN + 65450,

    SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_RIGHT_BANK_0 = SPR_CSG_BEGIN + 65451,
    SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_RIGHT_BANK_1 = SPR_CSG_BEGIN + 65452,
    SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_RIGHT_BANK_2 = SPR_CSG_BEGIN + 65453,
    SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_RIGHT_BANK_3 = SPR_CSG_BEGIN + 65454,

    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_0 = SPR_CSG_BEGIN + 65455,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_1 = SPR_CSG_BEGIN + 65456,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_2 = SPR_CSG_BEGIN + 65457,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_3 = SPR_CSG_BEGIN + 65458,

    SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_LEFT_BANK_0 = SPR_CSG_BEGIN + 65459,
    SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_LEFT_BANK_1 = SPR_CSG_BEGIN + 65460,
    SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_LEFT_BANK_2 = SPR_CSG_BEGIN + 65461,
    SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_LEFT_BANK_3 = SPR_CSG_BEGIN + 65462,

    SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_RIGHT_BANK_0 = SPR_CSG_BEGIN + 65463,
    SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_RIGHT_BANK_1 = SPR_CSG_BEGIN + 65464,
    SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_RIGHT_BANK_2 = SPR_CSG_BEGIN + 65465,
    SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_RIGHT_BANK_3 = SPR_CSG_BEGIN + 65466,

    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_UP25_0 = SPR_CSG_BEGIN + 65467,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_UP25_1 = SPR_CSG_BEGIN + 65468,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_UP25_2 = SPR_CSG_BEGIN + 65469,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_UP25_3 = SPR_CSG_BEGIN + 65470,

    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_UP25_0 = SPR_CSG_BEGIN + 65471,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_UP25_1 = SPR_CSG_BEGIN + 65472,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_UP25_2 = SPR_CSG_BEGIN + 65473,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_UP25_3 = SPR_CSG_BEGIN + 65474,

    SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_LEFT_BANK_FRONT_1 = SPR_CSG_BEGIN + 65475,
    SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_LEFT_BANK_FRONT_3 = SPR_CSG_BEGIN + 65476,

    SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_RIGHT_BANK_FRONT_2 = SPR_CSG_BEGIN + 65477,

    SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_LEFT_BANK_FRONT_1 = SPR_CSG_BEGIN + 65478,
    SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_LEFT_BANK_FRONT_2 = SPR_CSG_BEGIN + 65479,

    SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_RIGHT_BANK_FRONT_1 = SPR_CSG_BEGIN + 65480,
    SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_RIGHT_BANK_FRONT_2 = SPR_CSG_BEGIN + 65481,

    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_UP25_FRONT_1 = SPR_CSG_BEGIN + 65482,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_UP25_FRONT_2 = SPR_CSG_BEGIN + 65483,

    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_UP25_FRONT_1 = SPR_CSG_BEGIN + 65484,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_UP25_FRONT_2 = SPR_CSG_BEGIN + 65485,

    SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_RIGHT_BANK_FRONT_0 = SPR_CSG_BEGIN + 65486,

    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_0_0 = SPR_CSG_BEGIN + 65585,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_1_0 = SPR_CSG_BEGIN + 65586,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_2_0 = SPR_CSG_BEGIN + 65587,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_3_0 = SPR_CSG_BEGIN + 65588,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_4_0 = SPR_CSG_BEGIN + 65589,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_0_1 = SPR_CSG_BEGIN + 65590,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_1_1 = SPR_CSG_BEGIN + 65591,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_2_1 = SPR_CSG_BEGIN + 65592,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_3_1 = SPR_CSG_BEGIN + 65593,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_4_1 = SPR_CSG_BEGIN + 65594,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_0_2 = SPR_CSG_BEGIN + 65595,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_1_2 = SPR_CSG_BEGIN + 65596,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_2_2 = SPR_CSG_BEGIN + 65597,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_3_2 = SPR_CSG_BEGIN + 65598,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_4_2 = SPR_CSG_BEGIN + 65599,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_0_3 = SPR_CSG_BEGIN + 65600,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_1_3 = SPR_CSG_BEGIN + 65601,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_2_3 = SPR_CSG_BEGIN + 65602,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_3_3 = SPR_CSG_BEGIN + 65603,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_4_3 = SPR_CSG_BEGIN + 65604,

    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_0_0 = SPR_CSG_BEGIN + 65605,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_1_0 = SPR_CSG_BEGIN + 65606,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_2_0 = SPR_CSG_BEGIN + 65607,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_3_0 = SPR_CSG_BEGIN + 65608,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_4_0 = SPR_CSG_BEGIN + 65609,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_0_2 = SPR_CSG_BEGIN + 65610,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_1_2 = SPR_CSG_BEGIN + 65611,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_2_2 = SPR_CSG_BEGIN + 65612,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_3_2 = SPR_CSG_BEGIN + 65613,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_4_2 = SPR_CSG_BEGIN + 65614,

    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_0_0 = SPR_CSG_BEGIN + 65615,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_1_0 = SPR_CSG_BEGIN + 65616,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_2_0 = SPR_CSG_BEGIN + 65617,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_3_0 = SPR_CSG_BEGIN + 65618,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_4_0 = SPR_CSG_BEGIN + 65619,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_0_1 = SPR_CSG_BEGIN + 65620,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_1_1 = SPR_CSG_BEGIN + 65621,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_2_1 = SPR_CSG_BEGIN + 65622,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_3_1 = SPR_CSG_BEGIN + 65623,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_4_1 = SPR_CSG_BEGIN + 65624,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_0_2 = SPR_CSG_BEGIN + 65625,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_1_2 = SPR_CSG_BEGIN + 65626,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_2_2 = SPR_CSG_BEGIN + 65627,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_3_2 = SPR_CSG_BEGIN + 65628,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_4_2 = SPR_CSG_BEGIN + 65629,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_0_3 = SPR_CSG_BEGIN + 65630,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_1_3 = SPR_CSG_BEGIN + 65631,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_2_3 = SPR_CSG_BEGIN + 65632,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_3_3 = SPR_CSG_BEGIN + 65633,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_4_3 = SPR_CSG_BEGIN + 65634,

    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_0_0 = SPR_CSG_BEGIN + 65635,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_1_0 = SPR_CSG_BEGIN + 65636,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_2_0 = SPR_CSG_BEGIN + 65637,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_3_0 = SPR_CSG_BEGIN + 65638,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_4_0 = SPR_CSG_BEGIN + 65639,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_0_2 = SPR_CSG_BEGIN + 65640,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_1_2 = SPR_CSG_BEGIN + 65641,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_2_2 = SPR_CSG_BEGIN + 65642,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_3_2 = SPR_CSG_BEGIN + 65643,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_4_2 = SPR_CSG_BEGIN + 65644,

    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_4_3 = SPR_CSG_BEGIN + 65645,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_3_3 = SPR_CSG_BEGIN + 65646,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_2_3 = SPR_CSG_BEGIN + 65647,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_1_3 = SPR_CSG_BEGIN + 65648,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_0_3 = SPR_CSG_BEGIN + 65649,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_4_0 = SPR_CSG_BEGIN + 65650,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_3_0 = SPR_CSG_BEGIN + 65651,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_2_0 = SPR_CSG_BEGIN + 65652,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_1_0 = SPR_CSG_BEGIN + 65653,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_0_0 = SPR_CSG_BEGIN + 65654,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_4_1 = SPR_CSG_BEGIN + 65655,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_3_1 = SPR_CSG_BEGIN + 65656,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_2_1 = SPR_CSG_BEGIN + 65657,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_1_1 = SPR_CSG_BEGIN + 65658,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_0_1 = SPR_CSG_BEGIN + 65659,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_4_2 = SPR_CSG_BEGIN + 65660,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_3_2 = SPR_CSG_BEGIN + 65661,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_2_2 = SPR_CSG_BEGIN + 65662,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_1_2 = SPR_CSG_BEGIN + 65663,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_0_2 = SPR_CSG_BEGIN + 65664,

    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_4_3 = SPR_CSG_BEGIN + 65665,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_3_3 = SPR_CSG_BEGIN + 65666,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_2_3 = SPR_CSG_BEGIN + 65667,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_1_3 = SPR_CSG_BEGIN + 65668,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_0_3 = SPR_CSG_BEGIN + 65669,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_4_1 = SPR_CSG_BEGIN + 65670,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_3_1 = SPR_CSG_BEGIN + 65671,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_2_1 = SPR_CSG_BEGIN + 65672,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_1_1 = SPR_CSG_BEGIN + 65673,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_0_1 = SPR_CSG_BEGIN + 65674,

    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_2_3 = SPR_CSG_BEGIN + 65849,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_1_3 = SPR_CSG_BEGIN + 65850,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_0_3 = SPR_CSG_BEGIN + 65851,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_2_0 = SPR_CSG_BEGIN + 65852,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_1_0 = SPR_CSG_BEGIN + 65853,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_0_0 = SPR_CSG_BEGIN + 65854,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_2_1 = SPR_CSG_BEGIN + 65855,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_1_1 = SPR_CSG_BEGIN + 65856,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_0_1 = SPR_CSG_BEGIN + 65857,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_2_2 = SPR_CSG_BEGIN + 65858,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_1_2 = SPR_CSG_BEGIN + 65859,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_0_2 = SPR_CSG_BEGIN + 65860,

    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_FRONT_2_3 = SPR_CSG_BEGIN + 65861,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_FRONT_1_3 = SPR_CSG_BEGIN + 65862,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_FRONT_0_3 = SPR_CSG_BEGIN + 65863,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_FRONT_2_1 = SPR_CSG_BEGIN + 65864,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_FRONT_1_1 = SPR_CSG_BEGIN + 65865,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_FRONT_0_1 = SPR_CSG_BEGIN + 65866,

    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_0_0 = SPR_CSG_BEGIN + 65867,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_1_0 = SPR_CSG_BEGIN + 65868,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_2_0 = SPR_CSG_BEGIN + 65869,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_0_1 = SPR_CSG_BEGIN + 65870,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_1_1 = SPR_CSG_BEGIN + 65871,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_2_1 = SPR_CSG_BEGIN + 65872,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_0_2 = SPR_CSG_BEGIN + 65873,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_1_2 = SPR_CSG_BEGIN + 65874,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_2_2 = SPR_CSG_BEGIN + 65875,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_0_3 = SPR_CSG_BEGIN + 65876,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_1_3 = SPR_CSG_BEGIN + 65877,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_2_3 = SPR_CSG_BEGIN + 65878,

    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_FRONT_0_0 = SPR_CSG_BEGIN + 65879,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_FRONT_1_0 = SPR_CSG_BEGIN + 65880,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_FRONT_2_0 = SPR_CSG_BEGIN + 65881,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_FRONT_0_2 = SPR_CSG_BEGIN + 65882,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_FRONT_1_2 = SPR_CSG_BEGIN + 65883,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_FRONT_2_2 = SPR_CSG_BEGIN + 65884,

    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_2_3 = SPR_CSG_BEGIN + 65885,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_1_3 = SPR_CSG_BEGIN + 65886,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_0_3 = SPR_CSG_BEGIN + 65887,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_2_0 = SPR_CSG_BEGIN + 65888,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_1_0 = SPR_CSG_BEGIN + 65889,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_0_0 = SPR_CSG_BEGIN + 65890,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_2_1 = SPR_CSG_BEGIN + 65891,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_1_1 = SPR_CSG_BEGIN + 65892,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_0_1 = SPR_CSG_BEGIN + 65893,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_2_2 = SPR_CSG_BEGIN + 65894,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_1_2 = SPR_CSG_BEGIN + 65895,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_0_2 = SPR_CSG_BEGIN + 65896,

    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_FRONT_2_3 = SPR_CSG_BEGIN + 65897,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_FRONT_1_3 = SPR_CSG_BEGIN + 65898,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_FRONT_0_3 = SPR_CSG_BEGIN + 65899,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_FRONT_2_1 = SPR_CSG_BEGIN + 65900,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_FRONT_1_1 = SPR_CSG_BEGIN + 65901,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_FRONT_0_1 = SPR_CSG_BEGIN + 65902,

    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_0_0 = SPR_CSG_BEGIN + 65955,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_1_0 = SPR_CSG_BEGIN + 65956,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_0_1 = SPR_CSG_BEGIN + 65957,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_1_1 = SPR_CSG_BEGIN + 65958,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_0_2 = SPR_CSG_BEGIN + 65959,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_1_2 = SPR_CSG_BEGIN + 65960,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_0_3 = SPR_CSG_BEGIN + 65961,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_1_3 = SPR_CSG_BEGIN + 65962,

    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_1_3 = SPR_CSG_BEGIN + 65963,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_0_3 = SPR_CSG_BEGIN + 65964,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_1_0 = SPR_CSG_BEGIN + 65965,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_0_0 = SPR_CSG_BEGIN + 65966,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_1_1 = SPR_CSG_BEGIN + 65967,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_0_1 = SPR_CSG_BEGIN + 65968,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_1_2 = SPR_CSG_BEGIN + 65969,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_0_2 = SPR_CSG_BEGIN + 65970,

    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_FRONT_0_0 = SPR_CSG_BEGIN + 65971,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_FRONT_1_0 = SPR_CSG_BEGIN + 65972,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_FRONT_1_1 = SPR_CSG_BEGIN + 65973,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_FRONT_0_2 = SPR_CSG_BEGIN + 65974,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_FRONT_1_2 = SPR_CSG_BEGIN + 65975,

    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_FRONT_1_3 = SPR_CSG_BEGIN + 65976,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_FRONT_0_3 = SPR_CSG_BEGIN + 65977,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_FRONT_1_1 = SPR_CSG_BEGIN + 65978,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_FRONT_0_1 = SPR_CSG_BEGIN + 65979,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_FRONT_1_2 = SPR_CSG_BEGIN + 65980,

    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_0 = SPR_CSG_BEGIN + 66049,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_1 = SPR_CSG_BEGIN + 66050,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_2 = SPR_CSG_BEGIN + 66051,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_3 = SPR_CSG_BEGIN + 66052,

    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_FRONT_0 = SPR_CSG_BEGIN + 66053,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_FRONT_2 = SPR_CSG_BEGIN + 66054,

    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_LEFT_BANK_0 = SPR_CSG_BEGIN + 66055,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_LEFT_BANK_1 = SPR_CSG_BEGIN + 66056,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_LEFT_BANK_2 = SPR_CSG_BEGIN + 66057,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_LEFT_BANK_3 = SPR_CSG_BEGIN + 66058,

    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_LEFT_BANK_FRONT_0 = SPR_CSG_BEGIN + 66059,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_LEFT_BANK_FRONT_2 = SPR_CSG_BEGIN + 66060,

    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_RIGHT_BANK_0 = SPR_CSG_BEGIN + 66061,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_RIGHT_BANK_1 = SPR_CSG_BEGIN + 66062,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_RIGHT_BANK_2 = SPR_CSG_BEGIN + 66063,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_RIGHT_BANK_3 = SPR_CSG_BEGIN + 66064,

    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_RIGHT_BANK_FRONT_0 = SPR_CSG_BEGIN + 66065,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_RIGHT_BANK_FRONT_2 = SPR_CSG_BEGIN + 66066,

    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_LEFT_BANK_0 = SPR_CSG_BEGIN + 66067,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_LEFT_BANK_1 = SPR_CSG_BEGIN + 66068,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_LEFT_BANK_2 = SPR_CSG_BEGIN + 66069,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_LEFT_BANK_3 = SPR_CSG_BEGIN + 66070,

    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_LEFT_BANK_FRONT_0 = SPR_CSG_BEGIN + 66071,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_LEFT_BANK_FRONT_2 = SPR_CSG_BEGIN + 66072,

    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_RIGHT_BANK_0 = SPR_CSG_BEGIN + 66073,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_RIGHT_BANK_1 = SPR_CSG_BEGIN + 66074,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_RIGHT_BANK_2 = SPR_CSG_BEGIN + 66075,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_RIGHT_BANK_3 = SPR_CSG_BEGIN + 66076,

    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_RIGHT_BANK_FRONT_0 = SPR_CSG_BEGIN + 66077,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_RIGHT_BANK_FRONT_2 = SPR_CSG_BEGIN + 66078,

    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_TO_25_DEG_UP_0 = SPR_CSG_BEGIN + 66079,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_TO_25_DEG_UP_1 = SPR_CSG_BEGIN + 66080,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_TO_25_DEG_UP_2 = SPR_CSG_BEGIN + 66081,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_TO_25_DEG_UP_3 = SPR_CSG_BEGIN + 66082,

    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_TO_25_DEG_UP_FRONT_0 = SPR_CSG_BEGIN + 66083,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_TO_25_DEG_UP_FRONT_2 = SPR_CSG_BEGIN + 66084,

    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_RIGHT_BANK_TO_25_DEG_UP_0 = SPR_CSG_BEGIN + 66085,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_RIGHT_BANK_TO_25_DEG_UP_1 = SPR_CSG_BEGIN + 66086,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_RIGHT_BANK_TO_25_DEG_UP_2 = SPR_CSG_BEGIN + 66087,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_RIGHT_BANK_TO_25_DEG_UP_3 = SPR_CSG_BEGIN + 66088,

    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_RIGHT_BANK_TO_25_DEG_UP_FRONT_0 = SPR_CSG_BEGIN + 66089,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_RIGHT_BANK_TO_25_DEG_UP_FRONT_2 = SPR_CSG_BEGIN + 66090,

    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_0_0 = SPR_CSG_BEGIN + 66139,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_1_0 = SPR_CSG_BEGIN + 66140,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_2_0 = SPR_CSG_BEGIN + 66141,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_3_0 = SPR_CSG_BEGIN + 66142,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_0_1 = SPR_CSG_BEGIN + 66143,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_1_1 = SPR_CSG_BEGIN + 66144,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_2_1 = SPR_CSG_BEGIN + 66145,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_3_1 = SPR_CSG_BEGIN + 66146,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_0_2 = SPR_CSG_BEGIN + 66147,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_1_2 = SPR_CSG_BEGIN + 66148,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_2_2 = SPR_CSG_BEGIN + 66149,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_3_2 = SPR_CSG_BEGIN + 66150,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_0_3 = SPR_CSG_BEGIN + 66151,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_1_3 = SPR_CSG_BEGIN + 66152,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_2_3 = SPR_CSG_BEGIN + 66153,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_3_3 = SPR_CSG_BEGIN + 66154,

    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_FRONT_0_0 = SPR_CSG_BEGIN + 66155,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_FRONT_1_0 = SPR_CSG_BEGIN + 66156,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_FRONT_2_0 = SPR_CSG_BEGIN + 66157,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_FRONT_3_0 = SPR_CSG_BEGIN + 66158,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_FRONT_0_2 = SPR_CSG_BEGIN + 66159,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_FRONT_1_2 = SPR_CSG_BEGIN + 66160,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_FRONT_2_2 = SPR_CSG_BEGIN + 66161,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_FRONT_3_2 = SPR_CSG_BEGIN + 66162,

    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_0_0 = SPR_CSG_BEGIN + 66163,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_1_0 = SPR_CSG_BEGIN + 66164,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_2_0 = SPR_CSG_BEGIN + 66165,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_3_0 = SPR_CSG_BEGIN + 66166,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_0_1 = SPR_CSG_BEGIN + 66167,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_1_1 = SPR_CSG_BEGIN + 66168,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_2_1 = SPR_CSG_BEGIN + 66169,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_3_1 = SPR_CSG_BEGIN + 66170,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_0_2 = SPR_CSG_BEGIN + 66171,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_1_2 = SPR_CSG_BEGIN + 66172,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_2_2 = SPR_CSG_BEGIN + 66173,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_3_2 = SPR_CSG_BEGIN + 66174,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_0_3 = SPR_CSG_BEGIN + 66175,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_1_3 = SPR_CSG_BEGIN + 66176,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_2_3 = SPR_CSG_BEGIN + 66177,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_3_3 = SPR_CSG_BEGIN + 66178,

    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_FRONT_0_1 = SPR_CSG_BEGIN + 66179,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_FRONT_1_1 = SPR_CSG_BEGIN + 66180,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_FRONT_2_1 = SPR_CSG_BEGIN + 66181,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_FRONT_3_1 = SPR_CSG_BEGIN + 66182,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_FRONT_0_3 = SPR_CSG_BEGIN + 66183,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_FRONT_1_3 = SPR_CSG_BEGIN + 66184,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_FRONT_2_3 = SPR_CSG_BEGIN + 66185,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_FRONT_3_3 = SPR_CSG_BEGIN + 66186,

    SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_LEFT_BANK_HANDRAIL_0 = SPR_CSG_BEGIN + 66203,
    SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_LEFT_BANK_HANDRAIL_1 = SPR_CSG_BEGIN + 66204,
    SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_LEFT_BANK_HANDRAIL_2 = SPR_CSG_BEGIN + 66205,
    SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_LEFT_BANK_HANDRAIL_3 = SPR_CSG_BEGIN + 66206,

    SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_RIGHT_BANK_HANDRAIL_0 = SPR_CSG_BEGIN + 66207,
    SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_RIGHT_BANK_HANDRAIL_1 = SPR_CSG_BEGIN + 66208,
    SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_RIGHT_BANK_HANDRAIL_2 = SPR_CSG_BEGIN + 66209,
    SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_RIGHT_BANK_HANDRAIL_3 = SPR_CSG_BEGIN + 66210,

    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_HANDRAIL_0 = SPR_CSG_BEGIN + 66211,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_HANDRAIL_1 = SPR_CSG_BEGIN + 66212,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_HANDRAIL_2 = SPR_CSG_BEGIN + 66213,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_HANDRAIL_3 = SPR_CSG_BEGIN + 66214,

    SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_LEFT_BANK_HANDRAIL_0 = SPR_CSG_BEGIN + 66215,
    SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_LEFT_BANK_HANDRAIL_1 = SPR_CSG_BEGIN + 66216,
    SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_LEFT_BANK_HANDRAIL_2 = SPR_CSG_BEGIN + 66217,
    SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_LEFT_BANK_HANDRAIL_3 = SPR_CSG_BEGIN + 66218,

    SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_RIGHT_BANK_HANDRAIL_0 = SPR_CSG_BEGIN + 66219,
    SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_RIGHT_BANK_HANDRAIL_1 = SPR_CSG_BEGIN + 66220,
    SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_RIGHT_BANK_HANDRAIL_2 = SPR_CSG_BEGIN + 66221,
    SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_RIGHT_BANK_HANDRAIL_3 = SPR_CSG_BEGIN + 66222,

    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_UP25_HANDRAIL_0 = SPR_CSG_BEGIN + 66223,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_UP25_HANDRAIL_1 = SPR_CSG_BEGIN + 66224,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_UP25_HANDRAIL_2 = SPR_CSG_BEGIN + 66225,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_UP25_HANDRAIL_3 = SPR_CSG_BEGIN + 66226,

    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_UP25_HANDRAIL_0 = SPR_CSG_BEGIN + 66227,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_UP25_HANDRAIL_1 = SPR_CSG_BEGIN + 66228,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_UP25_HANDRAIL_2 = SPR_CSG_BEGIN + 66229,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_UP25_HANDRAIL_3 = SPR_CSG_BEGIN + 66230,

    SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_LEFT_BANK_FRONT_HANDRAIL_1 = SPR_CSG_BEGIN + 66231,
    SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_LEFT_BANK_FRONT_HANDRAIL_3 = SPR_CSG_BEGIN + 66232,

    SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_RIGHT_BANK_FRONT_HANDRAIL_2 = SPR_CSG_BEGIN + 66233,

    SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_LEFT_BANK_FRONT_HANDRAIL_1 = SPR_CSG_BEGIN + 66234,
    SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_LEFT_BANK_FRONT_HANDRAIL_2 = SPR_CSG_BEGIN + 66235,

    SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_RIGHT_BANK_FRONT_HANDRAIL_1 = SPR_CSG_BEGIN + 66236,
    SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_RIGHT_BANK_FRONT_HANDRAIL_2 = SPR_CSG_BEGIN + 66237,

    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_UP25_FRONT_HANDRAIL_1 = SPR_CSG_BEGIN + 66238,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_UP25_FRONT_HANDRAIL_2 = SPR_CSG_BEGIN + 66239,

    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_UP25_FRONT_HANDRAIL_1 = SPR_CSG_BEGIN + 66240,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_UP25_FRONT_HANDRAIL_2 = SPR_CSG_BEGIN + 66241,

    SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_RIGHT_BANK_FRONT_HANDRAIL_0 = SPR_CSG_BEGIN + 66242,

    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_0_0 = SPR_CSG_BEGIN + 66341,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_1_0 = SPR_CSG_BEGIN + 66342,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_2_0 = SPR_CSG_BEGIN + 66343,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_3_0 = SPR_CSG_BEGIN + 66344,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_4_0 = SPR_CSG_BEGIN + 66345,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_0_1 = SPR_CSG_BEGIN + 66346,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_1_1 = SPR_CSG_BEGIN + 66347,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_2_1 = SPR_CSG_BEGIN + 66348,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_3_1 = SPR_CSG_BEGIN + 66349,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_4_1 = SPR_CSG_BEGIN + 66350,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_0_2 = SPR_CSG_BEGIN + 66351,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_1_2 = SPR_CSG_BEGIN + 66352,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_2_2 = SPR_CSG_BEGIN + 66353,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_3_2 = SPR_CSG_BEGIN + 66354,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_4_2 = SPR_CSG_BEGIN + 66355,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_0_3 = SPR_CSG_BEGIN + 66356,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_1_3 = SPR_CSG_BEGIN + 66357,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_2_3 = SPR_CSG_BEGIN + 66358,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_3_3 = SPR_CSG_BEGIN + 66359,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_4_3 = SPR_CSG_BEGIN + 66360,

    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_HANDRAIL_0_0 = SPR_CSG_BEGIN + 66361,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_HANDRAIL_1_0 = SPR_CSG_BEGIN + 66362,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_HANDRAIL_2_0 = SPR_CSG_BEGIN + 66363,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_HANDRAIL_3_0 = SPR_CSG_BEGIN + 66364,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_HANDRAIL_4_0 = SPR_CSG_BEGIN + 66365,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_HANDRAIL_0_2 = SPR_CSG_BEGIN + 66366,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_HANDRAIL_1_2 = SPR_CSG_BEGIN + 66367,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_HANDRAIL_2_2 = SPR_CSG_BEGIN + 66368,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_HANDRAIL_3_2 = SPR_CSG_BEGIN + 66369,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_HANDRAIL_4_2 = SPR_CSG_BEGIN + 66370,

    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_0_0 = SPR_CSG_BEGIN + 66371,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_1_0 = SPR_CSG_BEGIN + 66372,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_2_0 = SPR_CSG_BEGIN + 66373,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_3_0 = SPR_CSG_BEGIN + 66374,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_4_0 = SPR_CSG_BEGIN + 66375,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_0_1 = SPR_CSG_BEGIN + 66376,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_1_1 = SPR_CSG_BEGIN + 66377,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_2_1 = SPR_CSG_BEGIN + 66378,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_3_1 = SPR_CSG_BEGIN + 66379,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_4_1 = SPR_CSG_BEGIN + 66380,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_0_2 = SPR_CSG_BEGIN + 66381,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_1_2 = SPR_CSG_BEGIN + 66382,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_2_2 = SPR_CSG_BEGIN + 66383,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_3_2 = SPR_CSG_BEGIN + 66384,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_4_2 = SPR_CSG_BEGIN + 66385,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_0_3 = SPR_CSG_BEGIN + 66386,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_1_3 = SPR_CSG_BEGIN + 66387,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_2_3 = SPR_CSG_BEGIN + 66388,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_3_3 = SPR_CSG_BEGIN + 66389,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_4_3 = SPR_CSG_BEGIN + 66390,

    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_0_0 = SPR_CSG_BEGIN + 66391,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_1_0 = SPR_CSG_BEGIN + 66392,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_2_0 = SPR_CSG_BEGIN + 66393,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_3_0 = SPR_CSG_BEGIN + 66394,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_4_0 = SPR_CSG_BEGIN + 66395,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_0_2 = SPR_CSG_BEGIN + 66396,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_1_2 = SPR_CSG_BEGIN + 66397,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_2_2 = SPR_CSG_BEGIN + 66398,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_3_2 = SPR_CSG_BEGIN + 66399,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_4_2 = SPR_CSG_BEGIN + 66400,

    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_4_3 = SPR_CSG_BEGIN + 66401,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_3_3 = SPR_CSG_BEGIN + 66402,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_2_3 = SPR_CSG_BEGIN + 66403,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_1_3 = SPR_CSG_BEGIN + 66404,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_0_3 = SPR_CSG_BEGIN + 66405,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_4_0 = SPR_CSG_BEGIN + 66406,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_3_0 = SPR_CSG_BEGIN + 66407,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_2_0 = SPR_CSG_BEGIN + 66408,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_1_0 = SPR_CSG_BEGIN + 66409,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_0_0 = SPR_CSG_BEGIN + 66410,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_4_1 = SPR_CSG_BEGIN + 66411,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_3_1 = SPR_CSG_BEGIN + 66412,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_2_1 = SPR_CSG_BEGIN + 66413,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_1_1 = SPR_CSG_BEGIN + 66414,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_0_1 = SPR_CSG_BEGIN + 66415,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_4_2 = SPR_CSG_BEGIN + 66416,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_3_2 = SPR_CSG_BEGIN + 66417,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_2_2 = SPR_CSG_BEGIN + 66418,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_1_2 = SPR_CSG_BEGIN + 66419,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_0_2 = SPR_CSG_BEGIN + 66420,

    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_4_3 = SPR_CSG_BEGIN + 66421,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_3_3 = SPR_CSG_BEGIN + 66422,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_2_3 = SPR_CSG_BEGIN + 66423,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_1_3 = SPR_CSG_BEGIN + 66424,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_0_3 = SPR_CSG_BEGIN + 66425,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_4_1 = SPR_CSG_BEGIN + 66426,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_3_1 = SPR_CSG_BEGIN + 66427,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_2_1 = SPR_CSG_BEGIN + 66428,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_1_1 = SPR_CSG_BEGIN + 66429,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_0_1 = SPR_CSG_BEGIN + 66430,

    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_HANDRAIL_2_3 = SPR_CSG_BEGIN + 66605,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_HANDRAIL_1_3 = SPR_CSG_BEGIN + 66606,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_HANDRAIL_0_3 = SPR_CSG_BEGIN + 66607,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_HANDRAIL_2_0 = SPR_CSG_BEGIN + 66608,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_HANDRAIL_1_0 = SPR_CSG_BEGIN + 66609,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_HANDRAIL_0_0 = SPR_CSG_BEGIN + 66610,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_HANDRAIL_2_1 = SPR_CSG_BEGIN + 66611,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_HANDRAIL_1_1 = SPR_CSG_BEGIN + 66612,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_HANDRAIL_0_1 = SPR_CSG_BEGIN + 66613,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_HANDRAIL_2_2 = SPR_CSG_BEGIN + 66614,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_HANDRAIL_1_2 = SPR_CSG_BEGIN + 66615,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_HANDRAIL_0_2 = SPR_CSG_BEGIN + 66616,

    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_FRONT_HANDRAIL_2_3 = SPR_CSG_BEGIN + 66617,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_FRONT_HANDRAIL_1_3 = SPR_CSG_BEGIN + 66618,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_FRONT_HANDRAIL_0_3 = SPR_CSG_BEGIN + 66619,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_FRONT_HANDRAIL_2_1 = SPR_CSG_BEGIN + 66620,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_FRONT_HANDRAIL_1_1 = SPR_CSG_BEGIN + 66621,
    SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_FRONT_HANDRAIL_0_1 = SPR_CSG_BEGIN + 66622,

    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_0_0 = SPR_CSG_BEGIN + 66623,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_1_0 = SPR_CSG_BEGIN + 66624,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_2_0 = SPR_CSG_BEGIN + 66625,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_0_1 = SPR_CSG_BEGIN + 66626,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_1_1 = SPR_CSG_BEGIN + 66627,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_2_1 = SPR_CSG_BEGIN + 66628,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_0_2 = SPR_CSG_BEGIN + 66629,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_1_2 = SPR_CSG_BEGIN + 66630,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_2_2 = SPR_CSG_BEGIN + 66631,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_0_3 = SPR_CSG_BEGIN + 66632,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_1_3 = SPR_CSG_BEGIN + 66633,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_2_3 = SPR_CSG_BEGIN + 66634,

    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_FRONT_HANDRAIL_0_0 = SPR_CSG_BEGIN + 66635,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_FRONT_HANDRAIL_1_0 = SPR_CSG_BEGIN + 66636,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_FRONT_HANDRAIL_2_0 = SPR_CSG_BEGIN + 66637,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_FRONT_HANDRAIL_0_2 = SPR_CSG_BEGIN + 66638,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_FRONT_HANDRAIL_1_2 = SPR_CSG_BEGIN + 66639,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_FRONT_HANDRAIL_2_2 = SPR_CSG_BEGIN + 66640,

    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_2_3 = SPR_CSG_BEGIN + 66641,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_1_3 = SPR_CSG_BEGIN + 66642,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_0_3 = SPR_CSG_BEGIN + 66643,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_2_0 = SPR_CSG_BEGIN + 66644,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_1_0 = SPR_CSG_BEGIN + 66645,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_0_0 = SPR_CSG_BEGIN + 66646,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_2_1 = SPR_CSG_BEGIN + 66647,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_1_1 = SPR_CSG_BEGIN + 66648,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_0_1 = SPR_CSG_BEGIN + 66649,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_2_2 = SPR_CSG_BEGIN + 66650,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_1_2 = SPR_CSG_BEGIN + 66651,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_0_2 = SPR_CSG_BEGIN + 66652,

    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_FRONT_HANDRAIL_2_3 = SPR_CSG_BEGIN + 66653,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_FRONT_HANDRAIL_1_3 = SPR_CSG_BEGIN + 66654,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_FRONT_HANDRAIL_0_3 = SPR_CSG_BEGIN + 66655,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_FRONT_HANDRAIL_2_1 = SPR_CSG_BEGIN + 66656,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_FRONT_HANDRAIL_1_1 = SPR_CSG_BEGIN + 66657,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_FRONT_HANDRAIL_0_1 = SPR_CSG_BEGIN + 66658,

    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_HANDRAIL_0_0 = SPR_CSG_BEGIN + 66711,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_HANDRAIL_1_0 = SPR_CSG_BEGIN + 66712,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_HANDRAIL_0_1 = SPR_CSG_BEGIN + 66713,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_HANDRAIL_1_1 = SPR_CSG_BEGIN + 66714,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_HANDRAIL_0_2 = SPR_CSG_BEGIN + 66715,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_HANDRAIL_1_2 = SPR_CSG_BEGIN + 66716,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_HANDRAIL_0_3 = SPR_CSG_BEGIN + 66717,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_HANDRAIL_1_3 = SPR_CSG_BEGIN + 66718,

    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_HANDRAIL_1_3 = SPR_CSG_BEGIN + 66719,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_HANDRAIL_0_3 = SPR_CSG_BEGIN + 66720,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_HANDRAIL_1_0 = SPR_CSG_BEGIN + 66721,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_HANDRAIL_0_0 = SPR_CSG_BEGIN + 66722,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_HANDRAIL_1_1 = SPR_CSG_BEGIN + 66723,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_HANDRAIL_0_1 = SPR_CSG_BEGIN + 66724,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_HANDRAIL_1_2 = SPR_CSG_BEGIN + 66725,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_HANDRAIL_0_2 = SPR_CSG_BEGIN + 66726,

    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_FRONT_HANDRAIL_0_0 = SPR_CSG_BEGIN + 66727,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_FRONT_HANDRAIL_1_0 = SPR_CSG_BEGIN + 66728,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_FRONT_HANDRAIL_1_1 = SPR_CSG_BEGIN + 66729,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_FRONT_HANDRAIL_0_2 = SPR_CSG_BEGIN + 66730,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_FRONT_HANDRAIL_1_2 = SPR_CSG_BEGIN + 66731,

    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_FRONT_HANDRAIL_1_3 = SPR_CSG_BEGIN + 66732,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_FRONT_HANDRAIL_0_3 = SPR_CSG_BEGIN + 66733,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_FRONT_HANDRAIL_1_1 = SPR_CSG_BEGIN + 66734,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_FRONT_HANDRAIL_0_1 = SPR_CSG_BEGIN + 66735,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_FRONT_HANDRAIL_1_2 = SPR_CSG_BEGIN + 66736,

    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_HANDRAIL_0 = SPR_CSG_BEGIN + 66805,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_HANDRAIL_1 = SPR_CSG_BEGIN + 66806,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_HANDRAIL_2 = SPR_CSG_BEGIN + 66807,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_HANDRAIL_3 = SPR_CSG_BEGIN + 66808,

    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_FRONT_HANDRAIL_0 = SPR_CSG_BEGIN + 66809,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_FRONT_HANDRAIL_2 = SPR_CSG_BEGIN + 66810,

    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_LEFT_BANK_HANDRAIL_0 = SPR_CSG_BEGIN + 66811,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_LEFT_BANK_HANDRAIL_1 = SPR_CSG_BEGIN + 66812,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_LEFT_BANK_HANDRAIL_2 = SPR_CSG_BEGIN + 66813,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_LEFT_BANK_HANDRAIL_3 = SPR_CSG_BEGIN + 66814,

    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_LEFT_BANK_FRONT_HANDRAIL_0 = SPR_CSG_BEGIN + 66815,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_LEFT_BANK_FRONT_HANDRAIL_2 = SPR_CSG_BEGIN + 66816,

    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_RIGHT_BANK_HANDRAIL_0 = SPR_CSG_BEGIN + 66817,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_RIGHT_BANK_HANDRAIL_1 = SPR_CSG_BEGIN + 66818,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_RIGHT_BANK_HANDRAIL_2 = SPR_CSG_BEGIN + 66819,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_RIGHT_BANK_HANDRAIL_3 = SPR_CSG_BEGIN + 66820,

    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_RIGHT_BANK_FRONT_HANDRAIL_0 = SPR_CSG_BEGIN + 66821,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_RIGHT_BANK_FRONT_HANDRAIL_2 = SPR_CSG_BEGIN + 66822,

    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_LEFT_BANK_HANDRAIL_0 = SPR_CSG_BEGIN + 66823,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_LEFT_BANK_HANDRAIL_1 = SPR_CSG_BEGIN + 66824,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_LEFT_BANK_HANDRAIL_2 = SPR_CSG_BEGIN + 66825,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_LEFT_BANK_HANDRAIL_3 = SPR_CSG_BEGIN + 66826,

    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_LEFT_BANK_FRONT_HANDRAIL_0 = SPR_CSG_BEGIN + 66827,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_LEFT_BANK_FRONT_HANDRAIL_2 = SPR_CSG_BEGIN + 66828,

    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_RIGHT_BANK_HANDRAIL_0 = SPR_CSG_BEGIN + 66829,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_RIGHT_BANK_HANDRAIL_1 = SPR_CSG_BEGIN + 66830,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_RIGHT_BANK_HANDRAIL_2 = SPR_CSG_BEGIN + 66831,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_RIGHT_BANK_HANDRAIL_3 = SPR_CSG_BEGIN + 66832,

    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_RIGHT_BANK_FRONT_HANDRAIL_0 = SPR_CSG_BEGIN + 66833,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_RIGHT_BANK_FRONT_HANDRAIL_2 = SPR_CSG_BEGIN + 66834,

    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_TO_25_DEG_UP_HANDRAIL_0 = SPR_CSG_BEGIN + 66835,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_TO_25_DEG_UP_HANDRAIL_1 = SPR_CSG_BEGIN + 66836,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_TO_25_DEG_UP_HANDRAIL_2 = SPR_CSG_BEGIN + 66837,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_TO_25_DEG_UP_HANDRAIL_3 = SPR_CSG_BEGIN + 66838,

    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_TO_25_DEG_UP_FRONT_HANDRAIL_0 = SPR_CSG_BEGIN + 66839,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_TO_25_DEG_UP_FRONT_HANDRAIL_2 = SPR_CSG_BEGIN + 66840,

    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_RIGHT_BANK_TO_25_DEG_UP_HANDRAIL_0 = SPR_CSG_BEGIN + 66841,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_RIGHT_BANK_TO_25_DEG_UP_HANDRAIL_1 = SPR_CSG_BEGIN + 66842,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_RIGHT_BANK_TO_25_DEG_UP_HANDRAIL_2 = SPR_CSG_BEGIN + 66843,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_RIGHT_BANK_TO_25_DEG_UP_HANDRAIL_3 = SPR_CSG_BEGIN + 66844,

    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_RIGHT_BANK_TO_25_DEG_UP_FRONT_HANDRAIL_0 = SPR_CSG_BEGIN + 66845,
    SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_RIGHT_BANK_TO_25_DEG_UP_FRONT_HANDRAIL_2 = SPR_CSG_BEGIN + 66846,

    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_HANDRAIL_0_0 = SPR_CSG_BEGIN + 66895,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_HANDRAIL_1_0 = SPR_CSG_BEGIN + 66896,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_HANDRAIL_2_0 = SPR_CSG_BEGIN + 66897,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_HANDRAIL_3_0 = SPR_CSG_BEGIN + 66898,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_HANDRAIL_0_1 = SPR_CSG_BEGIN + 66899,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_HANDRAIL_1_1 = SPR_CSG_BEGIN + 66900,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_HANDRAIL_2_1 = SPR_CSG_BEGIN + 66901,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_HANDRAIL_3_1 = SPR_CSG_BEGIN + 66902,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_HANDRAIL_0_2 = SPR_CSG_BEGIN + 66903,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_HANDRAIL_1_2 = SPR_CSG_BEGIN + 66904,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_HANDRAIL_2_2 = SPR_CSG_BEGIN + 66905,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_HANDRAIL_3_2 = SPR_CSG_BEGIN + 66906,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_HANDRAIL_0_3 = SPR_CSG_BEGIN + 66907,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_HANDRAIL_1_3 = SPR_CSG_BEGIN + 66908,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_HANDRAIL_2_3 = SPR_CSG_BEGIN + 66909,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_HANDRAIL_3_3 = SPR_CSG_BEGIN + 66910,

    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_FRONT_HANDRAIL_0_0 = SPR_CSG_BEGIN + 66911,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_FRONT_HANDRAIL_1_0 = SPR_CSG_BEGIN + 66912,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_FRONT_HANDRAIL_2_0 = SPR_CSG_BEGIN + 66913,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_FRONT_HANDRAIL_3_0 = SPR_CSG_BEGIN + 66914,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_FRONT_HANDRAIL_0_2 = SPR_CSG_BEGIN + 66915,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_FRONT_HANDRAIL_1_2 = SPR_CSG_BEGIN + 66916,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_FRONT_HANDRAIL_2_2 = SPR_CSG_BEGIN + 66917,
    SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_FRONT_HANDRAIL_3_2 = SPR_CSG_BEGIN + 66918,

    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_HANDRAIL_0_0 = SPR_CSG_BEGIN + 66919,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_HANDRAIL_1_0 = SPR_CSG_BEGIN + 66920,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_HANDRAIL_2_0 = SPR_CSG_BEGIN + 66921,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_HANDRAIL_3_0 = SPR_CSG_BEGIN + 66922,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_HANDRAIL_0_1 = SPR_CSG_BEGIN + 66923,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_HANDRAIL_1_1 = SPR_CSG_BEGIN + 66924,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_HANDRAIL_2_1 = SPR_CSG_BEGIN + 66925,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_HANDRAIL_3_1 = SPR_CSG_BEGIN + 66926,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_HANDRAIL_0_2 = SPR_CSG_BEGIN + 66927,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_HANDRAIL_1_2 = SPR_CSG_BEGIN + 66928,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_HANDRAIL_2_2 = SPR_CSG_BEGIN + 66929,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_HANDRAIL_3_2 = SPR_CSG_BEGIN + 66930,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_HANDRAIL_0_3 = SPR_CSG_BEGIN + 66931,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_HANDRAIL_1_3 = SPR_CSG_BEGIN + 66932,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_HANDRAIL_2_3 = SPR_CSG_BEGIN + 66933,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_HANDRAIL_3_3 = SPR_CSG_BEGIN + 66934,

    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_FRONT_HANDRAIL_0_1 = SPR_CSG_BEGIN + 66935,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_FRONT_HANDRAIL_1_1 = SPR_CSG_BEGIN + 66936,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_FRONT_HANDRAIL_2_1 = SPR_CSG_BEGIN + 66937,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_FRONT_HANDRAIL_3_1 = SPR_CSG_BEGIN + 66938,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_FRONT_HANDRAIL_0_3 = SPR_CSG_BEGIN + 66939,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_FRONT_HANDRAIL_1_3 = SPR_CSG_BEGIN + 66940,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_FRONT_HANDRAIL_2_3 = SPR_CSG_BEGIN + 66941,
    SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_FRONT_HANDRAIL_3_3 = SPR_CSG_BEGIN + 66942,
};

static constexpr std::array<WoodenTrackSection, kNumOrthogonalDirections> kFlatToLeftBankImages = { {
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_LEFT_BANK_0,
        SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_LEFT_BANK_HANDRAIL_0,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_LEFT_BANK_1,
        SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_LEFT_BANK_HANDRAIL_1,
        SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_LEFT_BANK_FRONT_1,
        SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_LEFT_BANK_FRONT_HANDRAIL_1,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_LEFT_BANK_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_LEFT_BANK_HANDRAIL_2,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_LEFT_BANK_3,
        SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_LEFT_BANK_HANDRAIL_3,
        SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_LEFT_BANK_FRONT_3,
        SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_LEFT_BANK_FRONT_HANDRAIL_3,
    },
} };

static constexpr std::array<WoodenTrackSection, kNumOrthogonalDirections> kFlatToRightBankImages = { {
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_RIGHT_BANK_0,
        SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_RIGHT_BANK_HANDRAIL_0,
        SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_RIGHT_BANK_FRONT_0,
        SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_RIGHT_BANK_FRONT_HANDRAIL_0,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_RIGHT_BANK_1,
        SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_RIGHT_BANK_HANDRAIL_1,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_RIGHT_BANK_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_RIGHT_BANK_HANDRAIL_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_RIGHT_BANK_FRONT_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_RIGHT_BANK_FRONT_HANDRAIL_2,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_RIGHT_BANK_3,
        SPR_CLASSIC_WOODEN_TWISTER_RC_FLAT_TO_RIGHT_BANK_HANDRAIL_3,
    },
} };

static constexpr std::array<WoodenTrackSection, kNumOrthogonalDirections> kLeftBankImages = { {
    { SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_0, SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_HANDRAIL_0 },
    { SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_1, SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_HANDRAIL_1 },
    { SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_2, SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_HANDRAIL_2 },
    { SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_3, SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_HANDRAIL_3 },
} };

static constexpr std::array<WoodenTrackSection, kNumOrthogonalDirections> kUp25ToLeftBankImages = { {
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_LEFT_BANK_0,
        SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_LEFT_BANK_HANDRAIL_0,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_LEFT_BANK_1,
        SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_LEFT_BANK_HANDRAIL_1,
        SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_LEFT_BANK_FRONT_1,
        SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_LEFT_BANK_FRONT_HANDRAIL_1,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_LEFT_BANK_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_LEFT_BANK_HANDRAIL_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_LEFT_BANK_FRONT_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_LEFT_BANK_FRONT_HANDRAIL_2,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_LEFT_BANK_3,
        SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_LEFT_BANK_HANDRAIL_3,
    },
} };

static constexpr std::array<WoodenTrackSection, kNumOrthogonalDirections> kUp25ToRightBankImages = { {
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_RIGHT_BANK_0,
        SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_RIGHT_BANK_HANDRAIL_0,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_RIGHT_BANK_1,
        SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_RIGHT_BANK_HANDRAIL_1,
        SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_RIGHT_BANK_FRONT_1,
        SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_RIGHT_BANK_FRONT_HANDRAIL_1,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_RIGHT_BANK_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_RIGHT_BANK_HANDRAIL_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_RIGHT_BANK_FRONT_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_RIGHT_BANK_FRONT_HANDRAIL_2,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_RIGHT_BANK_3,
        SPR_CLASSIC_WOODEN_TWISTER_RC_UP25_TO_RIGHT_BANK_HANDRAIL_3,
    },
} };

static constexpr std::array<WoodenTrackSection, kNumOrthogonalDirections> kLeftBankToUp25Images = { {
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_UP25_0,
        SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_UP25_HANDRAIL_0,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_UP25_1,
        SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_UP25_HANDRAIL_1,
        SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_UP25_FRONT_1,
        SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_UP25_FRONT_HANDRAIL_1,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_UP25_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_UP25_HANDRAIL_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_UP25_FRONT_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_UP25_FRONT_HANDRAIL_2,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_UP25_3,
        SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_UP25_HANDRAIL_3,
    },
} };

static constexpr std::array<WoodenTrackSection, kNumOrthogonalDirections> kRightBankToUp25Images = { {
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_UP25_0,
        SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_UP25_HANDRAIL_0,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_UP25_1,
        SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_UP25_HANDRAIL_1,
        SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_UP25_FRONT_1,
        SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_UP25_FRONT_HANDRAIL_1,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_UP25_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_UP25_HANDRAIL_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_UP25_FRONT_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_UP25_FRONT_HANDRAIL_2,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_UP25_3,
        SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_UP25_HANDRAIL_3,
    },
} };

static constexpr std::array<std::array<WoodenTrackSection, kNumOrthogonalDirections>, 3> kBankedQuarterTurn3Images = { {
    { {
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_0_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_HANDRAIL_0_0,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_0_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_HANDRAIL_0_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_FRONT_0_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_FRONT_HANDRAIL_0_1,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_0_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_HANDRAIL_0_2,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_0_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_HANDRAIL_0_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_FRONT_0_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_FRONT_HANDRAIL_0_3,
        },
    } },
    { {
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_1_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_HANDRAIL_1_0,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_1_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_HANDRAIL_1_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_FRONT_1_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_FRONT_HANDRAIL_1_1,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_1_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_HANDRAIL_1_2,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_1_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_HANDRAIL_1_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_FRONT_1_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_FRONT_HANDRAIL_1_3,
        },
    } },
    { {
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_2_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_HANDRAIL_2_0,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_2_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_HANDRAIL_2_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_FRONT_2_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_FRONT_HANDRAIL_2_1,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_2_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_HANDRAIL_2_2,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_2_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_HANDRAIL_2_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_FRONT_2_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_3_FRONT_HANDRAIL_2_3,
        },
    } },
} };

static constexpr std::array<std::array<WoodenTrackSection, kNumOrthogonalDirections>, 5> kBankedQuarterTurn5Images = { {
    { {
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_0_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_0_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_0_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_HANDRAIL_0_0,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_0_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_0_1,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_0_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_0_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_0_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_HANDRAIL_0_2,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_0_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_0_3,
        },
    } },
    { {
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_1_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_1_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_1_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_HANDRAIL_1_0,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_1_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_1_1,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_1_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_1_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_1_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_HANDRAIL_1_2,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_1_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_1_3,
        },
    } },
    { {
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_2_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_2_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_2_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_HANDRAIL_2_0,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_2_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_2_1,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_2_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_2_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_2_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_HANDRAIL_2_2,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_2_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_2_3,
        },
    } },
    { {
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_3_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_3_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_3_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_HANDRAIL_3_0,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_3_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_3_1,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_3_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_3_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_3_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_HANDRAIL_3_2,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_3_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_3_3,
        },
    } },
    { {
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_4_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_4_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_4_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_HANDRAIL_4_0,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_4_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_4_1,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_4_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_4_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_4_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_FRONT_HANDRAIL_4_2,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_4_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_BANKED_QUARTER_TURN_5_HANDRAIL_4_3,
        },
    } },
} };

static constexpr std::array<std::array<WoodenTrackSection, kNumOrthogonalDirections>, 3> kLeftHalfBankedHelixUpSmallImages = { {
    { {
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_0_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_0_0,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_0_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_0_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_FRONT_0_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_FRONT_HANDRAIL_0_1,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_0_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_0_2,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_0_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_0_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_FRONT_0_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_FRONT_HANDRAIL_0_3,
        },
    } },
    { {
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_1_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_1_0,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_1_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_1_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_FRONT_1_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_FRONT_HANDRAIL_1_1,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_1_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_1_2,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_1_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_1_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_FRONT_1_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_FRONT_HANDRAIL_1_3,
        },
    } },
    { {
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_2_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_2_0,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_2_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_2_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_FRONT_2_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_FRONT_HANDRAIL_2_1,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_2_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_2_2,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_2_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_2_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_FRONT_2_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_UP_SMALL_FRONT_HANDRAIL_2_3,
        },
    } },
} };

static constexpr std::array<std::array<WoodenTrackSection, kNumOrthogonalDirections>, 3> kRightHalfBankedHelixUpSmallImages = {
    {
        { {
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_0_0,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_0_0,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_FRONT_0_0,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_FRONT_HANDRAIL_0_0,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_0_1,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_0_1,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_0_2,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_0_2,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_FRONT_0_2,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_FRONT_HANDRAIL_0_2,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_0_3,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_0_3,
            },
        } },
        { {
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_1_0,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_1_0,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_FRONT_1_0,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_FRONT_HANDRAIL_1_0,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_1_1,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_1_1,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_1_2,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_1_2,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_FRONT_1_2,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_FRONT_HANDRAIL_1_2,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_1_3,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_1_3,
            },
        } },
        { {
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_2_0,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_2_0,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_FRONT_2_0,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_FRONT_HANDRAIL_2_0,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_2_1,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_2_1,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_2_2,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_2_2,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_FRONT_2_2,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_FRONT_HANDRAIL_2_2,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_2_3,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_UP_SMALL_HANDRAIL_2_3,
            },
        } },
    }
};

static constexpr std::array<std::array<WoodenTrackSection, kNumOrthogonalDirections>, 5> kLeftHalfBankedHelixUpLargeImages = { {
    { {
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_0_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_0_0,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_0_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_0_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_0_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_0_1,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_0_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_0_2,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_0_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_0_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_0_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_0_3,
        },
    } },
    { {
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_1_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_1_0,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_1_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_1_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_1_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_1_1,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_1_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_1_2,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_1_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_1_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_1_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_1_3,
        },
    } },
    { {
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_2_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_2_0,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_2_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_2_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_2_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_2_1,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_2_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_2_2,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_2_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_2_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_2_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_2_3,
        },
    } },
    { {
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_3_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_3_0,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_3_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_3_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_3_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_3_1,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_3_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_3_2,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_3_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_3_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_3_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_3_3,
        },
    } },
    { {
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_4_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_4_0,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_4_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_4_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_4_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_4_1,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_4_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_4_2,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_4_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_4_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_4_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_4_3,
        },
    } },
} };

static constexpr std::array<std::array<WoodenTrackSection, kNumOrthogonalDirections>, 5> kRightHalfBankedHelixUpLargeImages = {
    {
        { {
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_0_0,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_0_0,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_0_0,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_0_0,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_0_1,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_0_1,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_0_2,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_0_2,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_0_2,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_0_2,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_0_3,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_0_3,
            },
        } },
        { {
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_1_0,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_1_0,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_1_0,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_1_0,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_1_1,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_1_1,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_1_2,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_1_2,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_1_2,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_1_2,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_1_3,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_1_3,
            },
        } },
        { {
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_2_0,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_2_0,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_2_0,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_2_0,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_2_1,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_2_1,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_2_2,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_2_2,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_2_2,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_2_2,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_2_3,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_2_3,
            },
        } },
        { {
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_3_0,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_3_0,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_3_0,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_3_0,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_3_1,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_3_1,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_3_2,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_3_2,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_3_2,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_3_2,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_3_3,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_3_3,
            },
        } },
        { {
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_4_0,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_4_0,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_4_0,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_4_0,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_4_1,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_4_1,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_4_2,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_4_2,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_4_2,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_FRONT_HANDRAIL_4_2,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_4_3,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_HALF_BANKED_HELIX_LARGE_UP_HANDRAIL_4_3,
            },
        } },
    }
};

static constexpr std::array<std::array<WoodenTrackSection, kNumOrthogonalDirections>, 2>
    kLeftBankToLeftQuarterTurn325DegUpImages = { {
        { {
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_0_0,
                SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_HANDRAIL_0_0,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_0_1,
                SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_HANDRAIL_0_1,
                SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_FRONT_0_1,
                SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_FRONT_HANDRAIL_0_1,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_0_2,
                SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_HANDRAIL_0_2,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_0_3,
                SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_HANDRAIL_0_3,
                SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_FRONT_0_3,
                SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_FRONT_HANDRAIL_0_3,
            },
        } },
        { {
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_1_0,
                SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_HANDRAIL_1_0,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_1_1,
                SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_HANDRAIL_1_1,
                SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_FRONT_1_1,
                SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_FRONT_HANDRAIL_1_1,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_1_2,
                SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_HANDRAIL_1_2,
                SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_FRONT_1_2,
                SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_FRONT_HANDRAIL_1_2,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_1_3,
                SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_HANDRAIL_1_3,
                SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_FRONT_1_3,
                SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_BANK_TO_LEFT_QUARTER_TURN_3_25_DEG_UP_FRONT_HANDRAIL_1_3,
            },
        } },
    } };

static constexpr std::array<std::array<WoodenTrackSection, kNumOrthogonalDirections>, 2>
    kRightBankToRightQuarterTurn325DegUpImages = { {
        { {
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_0_0,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_HANDRAIL_0_0,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_FRONT_0_0,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_FRONT_HANDRAIL_0_0,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_0_1,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_HANDRAIL_0_1,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_0_2,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_HANDRAIL_0_2,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_FRONT_0_2,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_FRONT_HANDRAIL_0_2,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_0_3,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_HANDRAIL_0_3,
            },
        } },
        { {
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_1_0,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_HANDRAIL_1_0,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_FRONT_1_0,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_FRONT_HANDRAIL_1_0,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_1_1,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_HANDRAIL_1_1,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_FRONT_1_1,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_FRONT_HANDRAIL_1_1,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_1_2,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_HANDRAIL_1_2,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_FRONT_1_2,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_FRONT_HANDRAIL_1_2,
            },
            {
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_1_3,
                SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_BANK_TO_RIGHT_QUARTER_TURN_3_25_DEG_UP_HANDRAIL_1_3,
            },
        } },
    } };

static constexpr std::array<WoodenTrackSection, kNumOrthogonalDirections> kDiagFlatToLeftBankImages = { {
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_LEFT_BANK_0,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_LEFT_BANK_HANDRAIL_0,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_LEFT_BANK_FRONT_0,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_LEFT_BANK_FRONT_HANDRAIL_0,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_LEFT_BANK_1,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_LEFT_BANK_HANDRAIL_1,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_LEFT_BANK_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_LEFT_BANK_HANDRAIL_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_LEFT_BANK_FRONT_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_LEFT_BANK_FRONT_HANDRAIL_2,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_LEFT_BANK_3,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_LEFT_BANK_HANDRAIL_3,
    },
} };

static constexpr std::array<WoodenTrackSection, kNumOrthogonalDirections> kDiagFlatToRightBankImages = { {
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_RIGHT_BANK_0,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_RIGHT_BANK_HANDRAIL_0,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_RIGHT_BANK_FRONT_0,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_RIGHT_BANK_FRONT_HANDRAIL_0,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_RIGHT_BANK_1,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_RIGHT_BANK_HANDRAIL_1,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_RIGHT_BANK_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_RIGHT_BANK_HANDRAIL_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_RIGHT_BANK_FRONT_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_RIGHT_BANK_FRONT_HANDRAIL_2,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_RIGHT_BANK_3,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_FLAT_TO_RIGHT_BANK_HANDRAIL_3,
    },
} };

static constexpr std::array<WoodenTrackSection, kNumOrthogonalDirections> kDiagLeftBankTo25DegUpImages = { {
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_TO_25_DEG_UP_0,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_TO_25_DEG_UP_HANDRAIL_0,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_TO_25_DEG_UP_FRONT_0,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_TO_25_DEG_UP_FRONT_HANDRAIL_0,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_TO_25_DEG_UP_1,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_TO_25_DEG_UP_HANDRAIL_1,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_TO_25_DEG_UP_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_TO_25_DEG_UP_HANDRAIL_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_TO_25_DEG_UP_FRONT_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_TO_25_DEG_UP_FRONT_HANDRAIL_2,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_TO_25_DEG_UP_3,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_TO_25_DEG_UP_HANDRAIL_3,
    },
} };

static constexpr std::array<WoodenTrackSection, kNumOrthogonalDirections> kDiagRightBankTo25DegUpImages = { {
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_RIGHT_BANK_TO_25_DEG_UP_0,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_RIGHT_BANK_TO_25_DEG_UP_HANDRAIL_0,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_RIGHT_BANK_TO_25_DEG_UP_FRONT_0,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_RIGHT_BANK_TO_25_DEG_UP_FRONT_HANDRAIL_0,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_RIGHT_BANK_TO_25_DEG_UP_1,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_RIGHT_BANK_TO_25_DEG_UP_HANDRAIL_1,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_RIGHT_BANK_TO_25_DEG_UP_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_RIGHT_BANK_TO_25_DEG_UP_HANDRAIL_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_RIGHT_BANK_TO_25_DEG_UP_FRONT_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_RIGHT_BANK_TO_25_DEG_UP_FRONT_HANDRAIL_2,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_RIGHT_BANK_TO_25_DEG_UP_3,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_RIGHT_BANK_TO_25_DEG_UP_HANDRAIL_3,
    },
} };

static constexpr std::array<WoodenTrackSection, kNumOrthogonalDirections> kDiagUp25ToLeftBankImages = { {
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_LEFT_BANK_0,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_LEFT_BANK_HANDRAIL_0,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_LEFT_BANK_FRONT_0,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_LEFT_BANK_FRONT_HANDRAIL_0,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_LEFT_BANK_1,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_LEFT_BANK_HANDRAIL_1,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_LEFT_BANK_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_LEFT_BANK_HANDRAIL_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_LEFT_BANK_FRONT_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_LEFT_BANK_FRONT_HANDRAIL_2,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_LEFT_BANK_3,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_LEFT_BANK_HANDRAIL_3,
    },
} };

static constexpr std::array<WoodenTrackSection, kNumOrthogonalDirections> kDiagLeftBankImages = { {
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_0,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_HANDRAIL_0,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_FRONT_0,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_FRONT_HANDRAIL_0,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_1,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_HANDRAIL_1,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_HANDRAIL_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_FRONT_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_FRONT_HANDRAIL_2,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_3,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_LEFT_BANK_HANDRAIL_3,
    },
} };

static constexpr std::array<WoodenTrackSection, kNumOrthogonalDirections> kDiagUp25ToRightBankImages = { {
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_RIGHT_BANK_0,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_RIGHT_BANK_HANDRAIL_0,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_RIGHT_BANK_FRONT_0,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_RIGHT_BANK_FRONT_HANDRAIL_0,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_RIGHT_BANK_1,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_RIGHT_BANK_HANDRAIL_1,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_RIGHT_BANK_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_RIGHT_BANK_HANDRAIL_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_RIGHT_BANK_FRONT_2,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_RIGHT_BANK_FRONT_HANDRAIL_2,
    },
    {
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_RIGHT_BANK_3,
        SPR_CLASSIC_WOODEN_TWISTER_RC_DIAG_UP_25_TO_RIGHT_BANK_HANDRAIL_3,
    },
} };

static constexpr std::array<std::array<WoodenTrackSection, kNumOrthogonalDirections>, 4> kLeftEighthBankToDiagImages = { {
    { {
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_0_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_HANDRAIL_0_0,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_0_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_HANDRAIL_0_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_FRONT_0_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_FRONT_HANDRAIL_0_1,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_0_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_HANDRAIL_0_2,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_0_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_HANDRAIL_0_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_FRONT_0_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_FRONT_HANDRAIL_0_3,
        },
    } },
    { {
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_1_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_HANDRAIL_1_0,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_1_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_HANDRAIL_1_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_FRONT_1_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_FRONT_HANDRAIL_1_1,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_1_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_HANDRAIL_1_2,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_1_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_HANDRAIL_1_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_FRONT_1_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_FRONT_HANDRAIL_1_3,
        },
    } },
    { {
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_2_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_HANDRAIL_2_0,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_2_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_HANDRAIL_2_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_FRONT_2_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_FRONT_HANDRAIL_2_1,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_2_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_HANDRAIL_2_2,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_2_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_HANDRAIL_2_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_FRONT_2_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_FRONT_HANDRAIL_2_3,
        },
    } },
    { {
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_3_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_HANDRAIL_3_0,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_3_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_HANDRAIL_3_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_FRONT_3_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_FRONT_HANDRAIL_3_1,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_3_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_HANDRAIL_3_2,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_3_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_HANDRAIL_3_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_FRONT_3_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_LEFT_EIGHTH_BANK_TO_DIAG_FRONT_HANDRAIL_3_3,
        },
    } },
} };

static constexpr std::array<std::array<WoodenTrackSection, kNumOrthogonalDirections>, 4> kRightEighthBankToDiagImages = { {
    { {
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_0_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_HANDRAIL_0_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_FRONT_0_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_FRONT_HANDRAIL_0_0,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_0_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_HANDRAIL_0_1,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_0_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_HANDRAIL_0_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_FRONT_0_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_FRONT_HANDRAIL_0_2,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_0_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_HANDRAIL_0_3,
        },
    } },
    { {
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_1_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_HANDRAIL_1_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_FRONT_1_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_FRONT_HANDRAIL_1_0,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_1_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_HANDRAIL_1_1,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_1_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_HANDRAIL_1_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_FRONT_1_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_FRONT_HANDRAIL_1_2,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_1_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_HANDRAIL_1_3,
        },
    } },
    { {
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_2_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_HANDRAIL_2_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_FRONT_2_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_FRONT_HANDRAIL_2_0,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_2_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_HANDRAIL_2_1,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_2_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_HANDRAIL_2_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_FRONT_2_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_FRONT_HANDRAIL_2_2,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_2_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_HANDRAIL_2_3,
        },
    } },
    { {
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_3_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_HANDRAIL_3_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_FRONT_3_0,
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_FRONT_HANDRAIL_3_0,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_3_1,
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_HANDRAIL_3_1,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_3_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_HANDRAIL_3_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_FRONT_3_2,
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_FRONT_HANDRAIL_3_2,
        },
        {
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_3_3,
            SPR_CLASSIC_WOODEN_TWISTER_RC_RIGHT_EIGHTH_BANK_TO_DIAG_HANDRAIL_3_3,
        },
    } },
} };

static void ClassicWoodenTwisterRCTrackLeftBankToFlat(
    PaintSession& session, const Ride& ride, uint8_t trackSequence, uint8_t direction, int32_t height,
    const TrackElement& trackElement, SupportType supportType)
{
    TrackFlatToBank<false, kFlatToRightBankImages>(
        session, ride, trackSequence, DirectionReverse(direction), height, trackElement, supportType);
}

static void ClassicWoodenTwisterRCTrackRightBankToFlat(
    PaintSession& session, const Ride& ride, uint8_t trackSequence, uint8_t direction, int32_t height,
    const TrackElement& trackElement, SupportType supportType)
{
    TrackFlatToBank<false, kFlatToLeftBankImages>(
        session, ride, trackSequence, DirectionReverse(direction), height, trackElement, supportType);
}

static void ClassicWoodenTwisterRCTrackRightBank(
    PaintSession& session, const Ride& ride, uint8_t trackSequence, uint8_t direction, int32_t height,
    const TrackElement& trackElement, SupportType supportType)
{
    TrackFlatToBank<false, kLeftBankImages>(
        session, ride, trackSequence, DirectionReverse(direction), height, trackElement, supportType);
}

static void ClassicWoodenTwisterRCTrackLeftBankTo25DegDown(
    PaintSession& session, const Ride& ride, uint8_t trackSequence, uint8_t direction, int32_t height,
    const TrackElement& trackElement, SupportType supportType)
{
    Track25DegUpToBank<false, kUp25ToRightBankImages>(
        session, ride, trackSequence, DirectionReverse(direction), height, trackElement, supportType);
}

static void ClassicWoodenTwisterRCTrackRightBankTo25DegDown(
    PaintSession& session, const Ride& ride, uint8_t trackSequence, uint8_t direction, int32_t height,
    const TrackElement& trackElement, SupportType supportType)
{
    Track25DegUpToBank<false, kUp25ToLeftBankImages>(
        session, ride, trackSequence, DirectionReverse(direction), height, trackElement, supportType);
}

static void ClassicWoodenTwisterRCTrack25DegDownToLeftBank(
    PaintSession& session, const Ride& ride, uint8_t trackSequence, uint8_t direction, int32_t height,
    const TrackElement& trackElement, SupportType supportType)
{
    TrackBankTo25DegUp<false, kRightBankToUp25Images>(
        session, ride, trackSequence, DirectionReverse(direction), height, trackElement, supportType);
}

static void ClassicWoodenTwisterRCTrack25DegDownToRightBank(
    PaintSession& session, const Ride& ride, uint8_t trackSequence, uint8_t direction, int32_t height,
    const TrackElement& trackElement, SupportType supportType)
{
    TrackBankTo25DegUp<false, kLeftBankToUp25Images>(
        session, ride, trackSequence, DirectionReverse(direction), height, trackElement, supportType);
}

static void ClassicWoodenTwisterRCTrackRightQuarterTurn3Bank(
    PaintSession& session, const Ride& ride, uint8_t trackSequence, uint8_t direction, int32_t height,
    const TrackElement& trackElement, SupportType supportType)
{
    trackSequence = kMapLeftQuarterTurn3TilesToRightQuarterTurn3Tiles[trackSequence];
    TrackLeftQuarterTurn3Bank<false, kBankedQuarterTurn3Images>(
        session, ride, trackSequence, DirectionPrev(direction), height, trackElement, supportType);
}

static void ClassicWoodenTwisterRCTrackBankedLeftQuarterTurn5(
    PaintSession& session, const Ride& ride, uint8_t trackSequence, uint8_t direction, int32_t height,
    const TrackElement& trackElement, SupportType supportType)
{
    trackSequence = kMapLeftQuarterTurn5TilesToRightQuarterTurn5Tiles[trackSequence];
    TrackBankedRightQuarterTurn5<false, kBankedQuarterTurn5Images>(
        session, ride, trackSequence, DirectionNext(direction), height, trackElement, supportType);
}
static void ClassicWoodenTwisterRCTrackLeftHalfBankedHelixDownSmall(
    PaintSession& session, const Ride& ride, uint8_t trackSequence, uint8_t direction, int32_t height,
    const TrackElement& trackElement, SupportType supportType)
{
    if (trackSequence >= 4)
    {
        trackSequence -= 4;
        direction = DirectionPrev(direction);
    }
    trackSequence = kMapLeftQuarterTurn3TilesToRightQuarterTurn3Tiles[trackSequence];
    TrackRightHalfBankedHelixUpSmall<false, kRightHalfBankedHelixUpSmallImages>(
        session, ride, trackSequence, DirectionNext(direction), height, trackElement, supportType);
}

static void ClassicWoodenTwisterRCTrackRightHalfBankedHelixDownSmall(
    PaintSession& session, const Ride& ride, uint8_t trackSequence, uint8_t direction, int32_t height,
    const TrackElement& trackElement, SupportType supportType)
{
    if (trackSequence >= 4)
    {
        trackSequence -= 4;
        direction = DirectionNext(direction);
    }
    trackSequence = kMapLeftQuarterTurn3TilesToRightQuarterTurn3Tiles[trackSequence];
    TrackLeftHalfBankedHelixUpSmall<false, kLeftHalfBankedHelixUpSmallImages>(
        session, ride, trackSequence, DirectionPrev(direction), height, trackElement, supportType);
}

static void ClassicWoodenTwisterRCTrackLeftHalfBankedHelixDownLarge(
    PaintSession& session, const Ride& ride, uint8_t trackSequence, uint8_t direction, int32_t height,
    const TrackElement& trackElement, SupportType supportType)
{
    if (trackSequence >= 7)
    {
        trackSequence -= 7;
        direction = DirectionPrev(direction);
    }
    trackSequence = kMapLeftQuarterTurn5TilesToRightQuarterTurn5Tiles[trackSequence];
    TrackRightHalfBankedHelixUpLarge<false, kRightHalfBankedHelixUpLargeImages>(
        session, ride, trackSequence, DirectionNext(direction), height, trackElement, supportType);
}

static void ClassicWoodenTwisterRCTrackRightHalfBankedHelixDownLarge(
    PaintSession& session, const Ride& ride, uint8_t trackSequence, uint8_t direction, int32_t height,
    const TrackElement& trackElement, SupportType supportType)
{
    if (trackSequence >= 7)
    {
        trackSequence -= 7;
        direction = DirectionNext(direction);
    }
    trackSequence = kMapLeftQuarterTurn5TilesToRightQuarterTurn5Tiles[trackSequence];
    TrackLeftHalfBankedHelixUpLarge<false, kLeftHalfBankedHelixUpLargeImages>(
        session, ride, trackSequence, DirectionPrev(direction), height, trackElement, supportType);
}

static void ClassicWoodenTwisterRCTrackLeftQuarterTurn325DegDownToLeftBank(
    PaintSession& session, const Ride& ride, uint8_t trackSequence, uint8_t direction, int32_t height,
    const TrackElement& trackElement, SupportType supportType)
{
    trackSequence = kMapLeftQuarterTurn3TilesToRightQuarterTurn3Tiles[trackSequence];
    TrackRightBankToRightQuarterTurn325DegUp<false, kRightBankToRightQuarterTurn325DegUpImages>(
        session, ride, trackSequence, DirectionNext(direction), height, trackElement, supportType);
}

static void ClassicWoodenTwisterRCTrackRightQuarterTurn325DegDownToRightBank(
    PaintSession& session, const Ride& ride, uint8_t trackSequence, uint8_t direction, int32_t height,
    const TrackElement& trackElement, SupportType supportType)
{
    trackSequence = kMapLeftQuarterTurn3TilesToRightQuarterTurn3Tiles[trackSequence];
    TrackLeftBankToLeftQuarterTurn325DegUp<false, kLeftBankToLeftQuarterTurn325DegUpImages>(
        session, ride, trackSequence, DirectionPrev(direction), height, trackElement, supportType);
}

static void ClassicWoodenTwisterRCTrackDiagLeftBankToFlat(
    PaintSession& session, const Ride& ride, uint8_t trackSequence, uint8_t direction, int32_t height,
    const TrackElement& trackElement, SupportType supportType)
{
    trackSequence = kMapReversedDiagonalStraight[trackSequence];
    return TrackDiagFlatToBank<false, kDiagFlatToRightBankImages>(
        session, ride, trackSequence, DirectionReverse(direction), height, trackElement, supportType);
}

static void ClassicWoodenTwisterRCTrackDiagRightBankToFlat(
    PaintSession& session, const Ride& ride, uint8_t trackSequence, uint8_t direction, int32_t height,
    const TrackElement& trackElement, SupportType supportType)
{
    trackSequence = kMapReversedDiagonalStraight[trackSequence];
    return TrackDiagFlatToBank<false, kDiagFlatToLeftBankImages>(
        session, ride, trackSequence, DirectionReverse(direction), height, trackElement, supportType);
}

static void ClassicWoodenTwisterRCTrackDiagDown25ToLeftBank(
    PaintSession& session, const Ride& ride, uint8_t trackSequence, uint8_t direction, int32_t height,
    const TrackElement& trackElement, SupportType supportType)
{
    trackSequence = kMapReversedDiagonalStraight[trackSequence];
    return TrackDiagBankTo25DegUp<false, kDiagRightBankTo25DegUpImages>(
        session, ride, trackSequence, DirectionReverse(direction), height, trackElement, supportType);
}

static void ClassicWoodenTwisterRCTrackDiagDown25ToRightBank(
    PaintSession& session, const Ride& ride, uint8_t trackSequence, uint8_t direction, int32_t height,
    const TrackElement& trackElement, SupportType supportType)
{
    trackSequence = kMapReversedDiagonalStraight[trackSequence];
    return TrackDiagBankTo25DegUp<false, kDiagLeftBankTo25DegUpImages>(
        session, ride, trackSequence, DirectionReverse(direction), height, trackElement, supportType);
}

static void ClassicWoodenTwisterRCTrackDiagLeftBankToDown25(
    PaintSession& session, const Ride& ride, uint8_t trackSequence, uint8_t direction, int32_t height,
    const TrackElement& trackElement, SupportType supportType)
{
    trackSequence = kMapReversedDiagonalStraight[trackSequence];
    return TrackDiagUp25ToBank<false, kDiagUp25ToRightBankImages>(
        session, ride, trackSequence, DirectionReverse(direction), height, trackElement, supportType);
}

static void ClassicWoodenTwisterRCTrackDiagRightBankToDown25(
    PaintSession& session, const Ride& ride, uint8_t trackSequence, uint8_t direction, int32_t height,
    const TrackElement& trackElement, SupportType supportType)
{
    trackSequence = kMapReversedDiagonalStraight[trackSequence];
    return TrackDiagUp25ToBank<false, kDiagUp25ToLeftBankImages>(
        session, ride, trackSequence, DirectionReverse(direction), height, trackElement, supportType);
}

static void ClassicWoodenTwisterRCTrackDiagRightBank(
    PaintSession& session, const Ride& ride, uint8_t trackSequence, uint8_t direction, int32_t height,
    const TrackElement& trackElement, SupportType supportType)
{
    trackSequence = kMapReversedDiagonalStraight[trackSequence];
    return TrackDiagLeftBank<false, kDiagLeftBankImages>(
        session, ride, trackSequence, DirectionReverse(direction), height, trackElement, supportType);
}

static void ClassicWoodenTwisterRCTrackLeftEighthBankToOrthogonal(
    PaintSession& session, const Ride& ride, uint8_t trackSequence, uint8_t direction, int32_t height,
    const TrackElement& trackElement, SupportType supportType)
{
    trackSequence = mapLeftEighthTurnToOrthogonal[trackSequence];
    TrackRightEighthBankToDiag<false, kRightEighthBankToDiagImages>(
        session, ride, trackSequence, DirectionReverse(direction), height, trackElement, supportType);
}
static void ClassicWoodenTwisterRCTrackRightEighthBankToOrthogonal(
    PaintSession& session, const Ride& ride, uint8_t trackSequence, uint8_t direction, int32_t height,
    const TrackElement& trackElement, SupportType supportType)
{
    trackSequence = mapLeftEighthTurnToOrthogonal[trackSequence];
    TrackLeftEighthBankToDiag<false, kLeftEighthBankToDiagImages>(
        session, ride, trackSequence, DirectionPrev(direction), height, trackElement, supportType);
}

// Stylistically, this coaster is _very_ similar to the regular Wooden Roller Coaster.
// The only difference is the degree of the banking.
// As such, all non-banked pieces are simply drawn as regular wooden roller coaster pieces.
TrackPaintFunction GetTrackPaintFunctionClassicWoodenTwisterRC(TrackElemType trackType)
{
    if (!IsCsgLoaded())
    {
        return GetTrackPaintFunctionWoodenRC(trackType);
    }

    switch (trackType)
    {
        case TrackElemType::flatToLeftBank:
            return TrackFlatToBank<false, kFlatToLeftBankImages>;
        case TrackElemType::flatToRightBank:
            return TrackFlatToBank<false, kFlatToRightBankImages>;
        case TrackElemType::leftBankToFlat:
            return ClassicWoodenTwisterRCTrackLeftBankToFlat;
        case TrackElemType::rightBankToFlat:
            return ClassicWoodenTwisterRCTrackRightBankToFlat;
        case TrackElemType::leftBank:
            return TrackFlatToBank<false, kLeftBankImages>;
        case TrackElemType::rightBank:
            return ClassicWoodenTwisterRCTrackRightBank;
        case TrackElemType::up25ToLeftBank:
            return Track25DegUpToBank<false, kUp25ToLeftBankImages>;
        case TrackElemType::up25ToRightBank:
            return Track25DegUpToBank<false, kUp25ToRightBankImages>;
        case TrackElemType::leftBankToDown25:
            return ClassicWoodenTwisterRCTrackLeftBankTo25DegDown;
        case TrackElemType::rightBankToDown25:
            return ClassicWoodenTwisterRCTrackRightBankTo25DegDown;

        case TrackElemType::leftBankToUp25:
            return TrackBankTo25DegUp<false, kLeftBankToUp25Images>;
        case TrackElemType::rightBankToUp25:
            return TrackBankTo25DegUp<false, kRightBankToUp25Images>;
        case TrackElemType::down25ToLeftBank:
            return ClassicWoodenTwisterRCTrack25DegDownToLeftBank;
        case TrackElemType::down25ToRightBank:
            return ClassicWoodenTwisterRCTrack25DegDownToRightBank;

        case TrackElemType::leftBankedQuarterTurn3Tiles:
            return TrackLeftQuarterTurn3Bank<false, kBankedQuarterTurn3Images>;
        case TrackElemType::rightBankedQuarterTurn3Tiles:
            return ClassicWoodenTwisterRCTrackRightQuarterTurn3Bank;

        case TrackElemType::bankedLeftQuarterTurn5Tiles:
            return ClassicWoodenTwisterRCTrackBankedLeftQuarterTurn5;
        case TrackElemType::bankedRightQuarterTurn5Tiles:
            return TrackBankedRightQuarterTurn5<false, kBankedQuarterTurn5Images>;

        case TrackElemType::leftHalfBankedHelixUpSmall:
            return TrackLeftHalfBankedHelixUpSmall<false, kLeftHalfBankedHelixUpSmallImages>;
        case TrackElemType::rightHalfBankedHelixUpSmall:
            return TrackRightHalfBankedHelixUpSmall<false, kRightHalfBankedHelixUpSmallImages>;
        case TrackElemType::leftHalfBankedHelixDownSmall:
            return ClassicWoodenTwisterRCTrackLeftHalfBankedHelixDownSmall;
        case TrackElemType::rightHalfBankedHelixDownSmall:
            return ClassicWoodenTwisterRCTrackRightHalfBankedHelixDownSmall;

        case TrackElemType::leftHalfBankedHelixUpLarge:
            return TrackLeftHalfBankedHelixUpLarge<false, kLeftHalfBankedHelixUpLargeImages>;
        case TrackElemType::rightHalfBankedHelixUpLarge:
            return TrackRightHalfBankedHelixUpLarge<false, kRightHalfBankedHelixUpLargeImages>;
        case TrackElemType::leftHalfBankedHelixDownLarge:
            return ClassicWoodenTwisterRCTrackLeftHalfBankedHelixDownLarge;
        case TrackElemType::rightHalfBankedHelixDownLarge:
            return ClassicWoodenTwisterRCTrackRightHalfBankedHelixDownLarge;

        case TrackElemType::leftBankToLeftQuarterTurn3TilesUp25:
            return TrackLeftBankToLeftQuarterTurn325DegUp<false, kLeftBankToLeftQuarterTurn325DegUpImages>;
        case TrackElemType::rightBankToRightQuarterTurn3TilesUp25:
            return TrackRightBankToRightQuarterTurn325DegUp<false, kRightBankToRightQuarterTurn325DegUpImages>;
        case TrackElemType::leftQuarterTurn3TilesDown25ToLeftBank:
            return ClassicWoodenTwisterRCTrackLeftQuarterTurn325DegDownToLeftBank;
        case TrackElemType::rightQuarterTurn3TilesDown25ToRightBank:
            return ClassicWoodenTwisterRCTrackRightQuarterTurn325DegDownToRightBank;

        case TrackElemType::diagFlatToLeftBank:
            return TrackDiagFlatToBank<false, kDiagFlatToLeftBankImages>;
        case TrackElemType::diagFlatToRightBank:
            return TrackDiagFlatToBank<false, kDiagFlatToRightBankImages>;
        case TrackElemType::diagLeftBankToFlat:
            return ClassicWoodenTwisterRCTrackDiagLeftBankToFlat;
        case TrackElemType::diagRightBankToFlat:
            return ClassicWoodenTwisterRCTrackDiagRightBankToFlat;

        case TrackElemType::diagLeftBankToUp25:
            return TrackDiagBankTo25DegUp<false, kDiagLeftBankTo25DegUpImages>;
        case TrackElemType::diagRightBankToUp25:
            return TrackDiagBankTo25DegUp<false, kDiagRightBankTo25DegUpImages>;
        case TrackElemType::diagDown25ToLeftBank:
            return ClassicWoodenTwisterRCTrackDiagDown25ToLeftBank;
        case TrackElemType::diagDown25ToRightBank:
            return ClassicWoodenTwisterRCTrackDiagDown25ToRightBank;

        case TrackElemType::diagUp25ToLeftBank:
            return TrackDiagUp25ToBank<false, kDiagUp25ToLeftBankImages>;
        case TrackElemType::diagUp25ToRightBank:
            return TrackDiagUp25ToBank<false, kDiagUp25ToRightBankImages>;
        case TrackElemType::diagLeftBankToDown25:
            return ClassicWoodenTwisterRCTrackDiagLeftBankToDown25;
        case TrackElemType::diagRightBankToDown25:
            return ClassicWoodenTwisterRCTrackDiagRightBankToDown25;

        case TrackElemType::diagLeftBank:
            return TrackDiagLeftBank<false, kDiagLeftBankImages>;
        case TrackElemType::diagRightBank:
            return ClassicWoodenTwisterRCTrackDiagRightBank;

        case TrackElemType::leftEighthBankToDiag:
            return TrackLeftEighthBankToDiag<false, kLeftEighthBankToDiagImages>;
        case TrackElemType::rightEighthBankToDiag:
            return TrackRightEighthBankToDiag<false, kRightEighthBankToDiagImages>;
        case TrackElemType::leftEighthBankToOrthogonal:
            return ClassicWoodenTwisterRCTrackLeftEighthBankToOrthogonal;
        case TrackElemType::rightEighthBankToOrthogonal:
            return ClassicWoodenTwisterRCTrackRightEighthBankToOrthogonal;

        default:
            return GetTrackPaintFunctionWoodenRC(trackType);
    }
}
